@@ -76,8 +76,8 @@ class QuickbooksCore(SitesCore):
                         self.get_otp_code()
                     )
                     self.browser.click_element_when_visible('//input[@id="ius-mfa-otp-submit-btn"]')
-                self.wait_element('//div[@data-automation-id="cm_client_hub_business_name"]')
-                if self.does_element_displayed('//div[@data-automation-id="cm_client_hub_business_name"]'):
+                self.wait_element('//*[@data-id="navigation-container"]')
+                if self.does_element_displayed('//*[@data-id="navigation-container"]'):
                     self.base_url = self.get_base_url(self.browser.get_location())
                     self.is_site_available = True
                     return True
